==> eslint-plugin-jsx-a11y-0.6.1.tgz: package/lib/rules/img-uses-alt.js <==
/**
 * @fileoverview Enforce img tag uses alt attribute.
 * @author Ethan Cohen
 */
'use strict';

// ----------------------------------------------------------------------------
// Rule Definition
// ----------------------------------------------------------------------------

var _hasAttribute = require('../util/hasAttribute');

var _hasAttribute2 = _interopRequireDefault(_hasAttribute);

var _getAttributeValue = require('../util/getAttributeValue');

var _getAttributeValue2 = _interopRequireDefault(_getAttributeValue);

var _getNodeType = require('../util/getNodeType');

var _getNodeType2 = _interopRequireDefault(_getNodeType);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

module.exports = function (context) {
  return {
    JSXOpeningElement: function JSXOpeningElement(node) {
      var typeCheck = ['img'].concat(context.options[0]);
      var nodeType = (0, _getNodeType2.default)(node);

      // Only check 'img' elements and custom types.
      if (typeCheck.indexOf(nodeType) === -1) {
        return;
      }

      var hasAltProp = (0, _hasAttribute2.default)(node.attributes, 'alt');

      // Missing alt prop error.
      if (!hasAltProp) {
        context.report({
          node: node,
          message: nodeType + ' elements must have an alt prop.'
        });
        return;
      }

      // Check if alt prop is undefined.
      var altProp = (0, _getAttributeValue2.default)(hasAltProp);

      // Check if alt prop is ""
      var emptyAlt = hasAltProp && hasAltProp.value && hasAltProp.value.type === 'Literal' && hasAltProp.value.value === "";

      var hasRoleProp = (0, _hasAttribute2.default)(node.attributes, 'role');
      var roleProp = (0, _getAttributeValue2.default)(hasRoleProp);

      // Allow altProp to be "" if `role="presentation"` is present.
      var isValid = altProp || emptyAlt && hasRoleProp && roleProp.toUpperCase() === 'PRESENTATION';

      // Undefined alt prop error.
      if (!isValid) {
        context.report({
          node: node,
          message: nodeType + ' alt prop must have a value. You can set alt="" if role="presentation" is applied.'
        });
        return;
      }
    }
  };
};

module.exports.schema = [{
  "oneOf": [{ "type": "string" }, {
    "type": "array",
    "items": {
      "type": "string"
    },
    "minItems": 1,
    "uniqueItems": true
  }]
}];

==> eslint-plugin-jsx-a11y-0.6.2.tgz: package/lib/rules/img-uses-alt.js <==
/**
 * @fileoverview Enforce img tag uses alt attribute.
 * @author Ethan Cohen
 */
'use strict';

// ----------------------------------------------------------------------------
// Rule Definition
// ----------------------------------------------------------------------------

var _hasAttribute = require('../util/hasAttribute');

var _hasAttribute2 = _interopRequireDefault(_hasAttribute);

var _getAttributeValue = require('../util/getAttributeValue');

var _getAttributeValue2 = _interopRequireDefault(_getAttributeValue);

var _getNodeType = require('../util/getNodeType');

var _getNodeType2 = _interopRequireDefault(_getNodeType);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

module.exports = function (context) {
  return {
    JSXOpeningElement: function JSXOpeningElement(node) {
      var typeCheck = ['img'].concat(context.options[0]);
      var nodeType = (0, _getNodeType2.default)(node);

      // Only check 'img' elements and custom types.
      if (typeCheck.indexOf(nodeType) === -1) {
        return;
      }

      var hasRoleProp = (0, _hasAttribute2.default)(node.attributes, 'role');
      var roleValue = (0, _getAttributeValue2.default)(hasRoleProp);
      var isPresentation = hasRoleProp && roleValue.toLowerCase() === 'presentation';

      if (isPresentation) {
        return;
      }

      var hasAltProp = (0, _hasAttribute2.default)(node.attributes, 'alt');

      // Missing alt prop error.
      if (!hasAltProp) {
        context.report({
          node: node,
          message: nodeType + ' elements must have an alt prop or use role="presentation".'
        });
        return;
      }

      // Check if alt prop is undefined.
      var altValue = (0, _getAttributeValue2.default)(hasAltProp);

      if (altValue || altValue === '') {
        return;
      }

      // Undefined alt prop error.
      context.report({
        node: node,
        message: 'Invalid alt value for ' + nodeType + '. Use alt="" or role="presentation" for presentational images.'
      });
    }
  };
};

module.exports.schema = [{
  "oneOf": [{ "type": "string" }, {
    "type": "array",
    "items": {
      "type": "string"
    },
    "minItems": 1,
    "uniqueItems": true
  }]
}];
